Contact
=======

Bug reports, feedback
---------------------
.. _bug reports, feedback:

You think you have found a bug in Pylint? Well, this may be the case
since Pylint and Python are under heavy development!

Please take the time to check if it is already in the issue tracker at
https://github.com/pylint-dev/pylint

Note that the issue might also be reported in one of Pylint's major dependencies,
astroid:

* https://github.com/pylint-dev/astroid

Discord server
--------------

You can discuss your problem using the discord server:

https://discord.com/invite/Egy6P8AMB5

Mailing lists
-------------

.. _Mailing lists:

The code-quality mailing list is shared with other tools that aim
at improving the quality of python code.

You can subscribe to this mailing list at
https://mail.python.org/mailman3/lists/code-quality.python.org/

Archives are available at
https://mail.python.org/pipermail/code-quality/

Archives before April 2013 are not available anymore. At
https://mail.python.org/pipermail/ it was under ``python-projects``.

Support
-------

.. image:: media/Tidelift_Logos_RGB_Tidelift_Shorthand_On-White.png
   :height: 150
   :alt: Tidelift
   :align: left
   :class: tideliftlogo

Professional support for pylint is available as part of the `Tidelift
Subscription`_.  Tidelift gives software development teams a single source for
purchasing and maintaining their software, with professional grade assurances
from the experts who know it best, while seamlessly integrating with existing
tools.

.. _Tidelift Subscription: https://tidelift.com/subscription/pkg/pypi-pylint?utm_source=pypi-pylint&utm_medium=referral&utm_campaign=readme
